pub struct P2PBehaviour {
pub chat: Behaviour<ChatCodec>,
pub mailbox: Behaviour<MailboxCodec>,
pub discovery: DiscoveryBehaviour,
pub ping: Behaviour,
}Expand description
The composite NetworkBehaviour for the application.
This struct combines all the individual network behaviours into a single
behaviour that can be used by the libp2p Swarm.
Fields
chat: Behaviour<ChatCodec>The behaviour for sending and receiving chat messages.
mailbox: Behaviour<MailboxCodec>The behaviour for interacting with mailbox nodes.
discovery: DiscoveryBehaviourThe behaviour for peer discovery.
ping: BehaviourThe behaviour for pinging other peers to keep connections alive.